@@ -74,7 +74,7 @@ void wallPaeper::createAbtDialog() {
     // Only create a new dialog if it hasn't been made yet
     if(abtDialogExists == false) {
         abtDialog = new aboutDialog(this);
-        abtDialog->setWindowTitle("Wallpaeper 0.4 for Nokia N900");
+        abtDialog->setWindowTitle("Wallpaeper 0.4.1 for Nokia N900");
 
         abtDialog->ui->aboutText1->adjustSize();
         abtDialog->ui->aboutText2->adjustSize();
