@@ -1,8 +1,8 @@
 #ifndef WALLPAEPER_H
 #define WALLPAEPER_H
 
-#include "fourimages.h"
-#include "ui_fourimages.h"
+#include "wpnew.h"
+#include "ui_wpnew.h"
 #include "wpmanager.h"
 #include "ui_wpmanager.h"
 #include "aboutdialog.h"
@@ -34,12 +34,12 @@ private:
     bool abtDialogExists;
     aboutDialog* abtDialog;
 
-    fourImages* fourWin;
+    wpNew* newWin;
     wpManager* manWin;
 
 public slots:
     void createAbtDialog();
-    void fourBtnClicked();
+    void newBtnClicked();
     void manBtnClicked();
 };
 
