@@ -10,9 +10,13 @@ wpManager::wpManager(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    // Set the Images folder as the fixed path, filter on .desktop files
+    // Set the Images directory as the fixed path, filter on .desktop files
     imageSetDir.setPath("/home/user/MyDocs/.images/");
     nameFilters << "*.desktop";
+    // Make a watcher for the Images directory
+    watchDir.addPath(imageSetDir.absolutePath());
+    connect(&watchDir, SIGNAL(directoryChanged(QString)),
+            this, SLOT(updateList()));
 
     delDialogIsMade = false;
     fileView = filenames;
@@ -22,11 +26,11 @@ wpManager::wpManager(QWidget *parent) :
             this, SLOT(itemChanged()));
 
     connect(ui->manPrevBtn, SIGNAL(clicked()),
-            this, SLOT(manPrevBtnClicked()));
+            this, SLOT(updatePrevs()));
     connect(ui->manEditBtn, SIGNAL(clicked()),
-            this, SLOT(manEditBtnClicked()));
+            this, SLOT(editCurrent()));
     connect(ui->manDelBtn, SIGNAL(clicked()),
-            this, SLOT(manDelBtnClicked()));
+            this, SLOT(confirmDelSet()));
 
     for(i=0; i<4; i++)
         manPrev.append(new QLabel);
@@ -78,11 +82,19 @@ void wpManager::setupWPManMenuBar() {
 
 void wpManager::viewNames() {
     fileView = names;
-    updateList();
+    changeView();
 }
 void wpManager::viewFilenames() {
     fileView = filenames;
-    updateList();
+    changeView();
+}
+void wpManager::changeView() {
+    for(i=0; i<imageSetList.count(); i++) {
+        if(fileView == filenames)
+            ui->fileList->item(i)->setText(QFileInfo(imageSetList[i][0]).fileName());
+        else if(fileView == names)
+            ui->fileList->item(i)->setText(imageSetList[i][5]);
+    }
 }
 
 
@@ -90,19 +102,22 @@ void wpManager::viewFilenames() {
 
 
 void wpManager::updateList() {
+    // Before updating, save current row position
+    curRowBeforeUpdate = ui->fileList->currentRow();
+
     // Empty the lists before updating
     imageSetPreList.clear();
     imageSetList.clear();
     ui->fileList->clear();
 
-    // Put all the entries in Images folder (+filter) in imageSetPreList (QStringList)
+    // Put all the entries in Images directory (+filter) in imageSetPreList (QStringList)
     // Include hidden files
     imageSetPreList = imageSetDir.entryList(nameFilters, QDir::Files | QDir::Hidden);
 
     // Fill imageSetList with entries that contain "Type=Background Image"
     fillImageSetList();
 
-    // Fill ui->fileList (update)
+    // Put (file)names in fileList
     for(i=0; i<imageSetList.count(); i++) {
         if(fileView == filenames)
             itemList.append(new QListWidgetItem(QIcon(imageSetList[i][1]), QFileInfo(imageSetList[i][0]).fileName(), ui->fileList));
@@ -113,6 +128,8 @@ void wpManager::updateList() {
     // Clear the previews
     for(i=0; i<4; i++)
         manPrev[i]->setPixmap(QPixmap(""));
+
+    ui->fileList->setCurrentRow(curRowBeforeUpdate);
 }
 
 
@@ -185,27 +202,7 @@ void wpManager::fillImageSetList() {
 
 
 
-void wpManager::manPrevBtnClicked() {
-    fileExists = fileExistsCheck();
-    if(fileExists == true)
-        updatePrevs();
-}
-void wpManager::manEditBtnClicked() {
-    fileExists = fileExistsCheck();
-    if(fileExists == true)
-        editCurrent();
-}
-void wpManager::manDelBtnClicked() {
-    fileExists = fileExistsCheck();
-    if(fileExists == true)
-        confirmDelSet();
-}
-
-
-
-
-
-bool wpManager::fileExistsCheck() {
+bool wpManager::checkSelected() {
     // If none is selected
     if(ui->fileList->currentRow() <= -1) {
         QMaemo5InformationBox::information(this,
@@ -213,24 +210,8 @@ bool wpManager::fileExistsCheck() {
                                            QMaemo5InformationBox::DefaultTimeout);
         return false;
     }
-    // If a valid list-item has been selected
-    else if(ui->fileList->currentRow() >= 0) {
-        // If the .desktop file doesn't exist
-        if(QFile(imageSetList[ui->fileList->currentRow()][0]).exists() == false) {
-            QMaemo5InformationBox::information(this,
-                                               imageSetList[ui->fileList->currentRow()][0]
-                                               + tr(" doesn't exist (anymore).")
-                                               + "<br>"
-                                               + tr("Perhaps it has been deleted in the meantime?"),
-                                               QMaemo5InformationBox::NoTimeout);
-            updateList();
-            return false;
-        }
-        // Otherwise it does exist
-        else {
-            return true;
-        }
-    }
+    else
+        return true;
 }
 
 
@@ -238,24 +219,26 @@ bool wpManager::fileExistsCheck() {
 
 
 void wpManager::updatePrevs() {
-    // Update previews with Name
-    if(imageSetList[ui->fileList->currentRow()][5] == "")
-        ui->manPrevName->setText("<b>" + tr("(no name)") + "</b>");
-    else
-        ui->manPrevName->setText("<b>" + imageSetList[ui->fileList->currentRow()][5] + "</b>");
-
-    // Update previews with X-File#
-    for(i=0; i<4; i++) {
-        if(imageSetList[ui->fileList->currentRow()][i+1] == "") {
-            manPrev[i]->setPixmap(QPixmap(""));
-            manPrev[i]->setText(tr("(empty)"));
-        }
-        else if(QFile(imageSetList[ui->fileList->currentRow()][i+1]).exists() == false) {
-            manPrev[i]->setPixmap(QPixmap(""));
-            manPrev[i]->setText(tr("(doesn't") + "<br>" + tr("exist)"));
-        }
+    if(checkSelected() == true) {
+        // Update previews with Name
+        if(imageSetList[ui->fileList->currentRow()][5] == "")
+            ui->manPrevName->setText("<b>" + tr("(no name)") + "</b>");
         else
-            manPrev[i]->setPixmap(QPixmap(imageSetList[ui->fileList->currentRow()][i+1]));
+            ui->manPrevName->setText("<b>" + imageSetList[ui->fileList->currentRow()][5] + "</b>");
+
+        // Update previews with X-File#
+        for(i=0; i<4; i++) {
+            if(imageSetList[ui->fileList->currentRow()][i+1] == "") {
+                manPrev[i]->setPixmap(QPixmap(""));
+                manPrev[i]->setText(tr("(empty)"));
+            }
+            else if(QFile(imageSetList[ui->fileList->currentRow()][i+1]).exists() == false) {
+                manPrev[i]->setPixmap(QPixmap(""));
+                manPrev[i]->setText(tr("(doesn't") + "<br>" + tr("exist)"));
+            }
+            else
+                manPrev[i]->setPixmap(QPixmap(imageSetList[ui->fileList->currentRow()][i+1]));
+        }
     }
 }
 
@@ -264,44 +247,46 @@ void wpManager::updatePrevs() {
 
 
 void wpManager::editCurrent() {
-    // Create a new wpNew window for editing
-    editWin = new wpNew(this);
-    editWin->setAttribute(Qt::WA_Maemo5StackedWindow);
-    editWin->setAttribute(Qt::WA_DeleteOnClose);
-    connect(editWin, SIGNAL(destroyed()),
-            this, SLOT(updateListAfterEdit()));
+    if(checkSelected() == true) {
+        // Create a new wpNew window for editing
+        editWin = new wpNew(this);
+        editWin->setAttribute(Qt::WA_Maemo5StackedWindow);
+        editWin->setAttribute(Qt::WA_DeleteOnClose);
+        connect(editWin, SIGNAL(destroyed()),
+                this, SLOT(reselectAfterEdit()));
 
-    // Pass Name to editWin::nameEdit
-    editWin->ui->nameEdit->setText(imageSetList[ui->fileList->currentRow()][5]);
+        // Pass Name to editWin::nameEdit
+        editWin->ui->nameEdit->setText(imageSetList[ui->fileList->currentRow()][5]);
 
-    // Pass X-File# through 4 to editWin::imgPath[#]
-    for(i=0; i<4; i++) {
-        *editWin->imgPath[i] = imageSetList[ui->fileList->currentRow()][i+1];
-    }
-
-    // Put the "Invisible file" checkbox in the right state
-    if(QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName().startsWith("."))
-        editWin->ui->visibChkbox->setChecked(true);
-    else
-        editWin->ui->visibChkbox->setChecked(false);
-
-    // Update previews, buttons, copytobuttons
-    for(i=0; i<4; i++) {
-        editWin->updateImgBtnPrev(i);
-        if(QFile(*editWin->imgPath[i]).exists() == true) {
-            editWin->imgPrevName[i]->setText(QFileInfo(*editWin->imgPath[i]).fileName());
-            editWin->setupCopyToBtn(i);
+        // Pass X-File# through 4 to editWin::imgPath[#]
+        for(i=0; i<4; i++) {
+            *editWin->imgPath[i] = imageSetList[ui->fileList->currentRow()][i+1];
         }
+
+        // Put the "Invisible file" checkbox in the right state
+        if(QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName().startsWith("."))
+            editWin->ui->visibChkbox->setChecked(true);
+        else
+            editWin->ui->visibChkbox->setChecked(false);
+
+        // Update previews, buttons, copytobuttons
+        for(i=0; i<4; i++) {
+            editWin->updateImgBtnPrev(i);
+            if(QFile(*editWin->imgPath[i]).exists() == true) {
+                editWin->imgPrevName[i]->setText(QFileInfo(*editWin->imgPath[i]).fileName());
+                editWin->setupCopyToBtn(i);
+            }
+        }
+        editWin->updateSaveBtn();
+
+        // Pass the filename to editWin
+        editWin->saveFileName = QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName();
+
+        // Before opening, save current row position
+        curRowBeforeEdit = ui->fileList->currentRow();
+
+        editWin->show();
     }
-    editWin->updateSaveBtn();
-
-    // Pass the filename to editWin
-    editWin->saveFileName = QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName();
-
-    // Before opening, save current row position
-    curRowBeforeEdit = ui->fileList->currentRow();
-
-    editWin->show();
 }
 
 
@@ -309,30 +294,32 @@ void wpManager::editCurrent() {
 
 
 void wpManager::confirmDelSet() {
-    // Store filename with path in QFile delFileWithPath
-    delFileWithPath.setFileName(imageSetList[ui->fileList->currentRow()][0]);
+    if(checkSelected() == true) {
+        // Store filename with path in QFile delFileWithPath
+        delFileWithPath.setFileName(imageSetList[ui->fileList->currentRow()][0]);
 
-    // Don't create another QDialog if it has been made already, just update it
-    if(delDialogIsMade == false) {
-        delDialog = new deleteDialog(this);
+        // Don't create another QDialog if it has been made already, just update it
+        if(delDialogIsMade == false) {
+            delDialog = new deleteDialog(this);
 
-        connect(delDialog->ui->delBtnBox, SIGNAL(accepted()),
-                this, SLOT(delSet()));
-        connect(delDialog->ui->delBtnBox, SIGNAL(rejected()),
-                this->delDialog, SLOT(close()));
+            connect(delDialog->ui->delBtnBox, SIGNAL(accepted()),
+                    this, SLOT(delSet()));
+            connect(delDialog->ui->delBtnBox, SIGNAL(rejected()),
+                    this->delDialog, SLOT(close()));
 
-        delDialogIsMade = true;
+            delDialogIsMade = true;
+        }
+
+
+        delDialog->ui->delText->setText(tr("Delete this file?")
+                                        + "<br>"
+                                        + tr("Note: images are NOT deleted.")
+                                        + "<br><br>"
+                                        + QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName());
+        delDialog->ui->delText->adjustSize();
+        delDialog->adjustSize();
+        delDialog->show();
     }
-
-
-    delDialog->ui->delText->setText(tr("Delete this file?")
-                                    + "<br>"
-                                    + tr("Note: images are NOT deleted.")
-                                    + "<br><br>"
-                                    + QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName());
-    delDialog->ui->delText->adjustSize();
-    delDialog->adjustSize();
-    delDialog->show();
 }
 
 
@@ -347,7 +334,6 @@ void wpManager::delSet() {
                                            "<br>" + delFileWithPath.fileName() + "<br>"
                                            + "<b>" + tr("deleted!") + "</b><br>",
                                            QMaemo5InformationBox::NoTimeout);
-        updateList();
     }
     // Otherwise, the file doesn't exist, or needs permission
     else
@@ -375,8 +361,7 @@ void wpManager::itemChanged() {
 
 
 
-void wpManager::updateListAfterEdit() {
-    updateList();
+void wpManager::reselectAfterEdit() {
     // Reselect the row that was selected before editing
     ui->fileList->setCurrentRow(curRowBeforeEdit);
 }
